@@ -59,6 +59,7 @@
 #' @keywords visualization
 #' @example ./examples/tableplot.R
 #' @seealso \code{\link{itableplot}}
+#' @references \href{http://www.jds-online.com/file_download/379/JDS-1108.pdf}{Tennekes, M., Jonge, E. de, Daas, P.J.H. (2013) Visualizing and Inspecting Large Datasets with Tableplots, Journal of Data Science 11 (1), 43-58}
 #' @note In early development versions of \code{tabplot} (prior to version 1.0) it was possible to sort datasets on multiple columns. To increase to tableplot creation speed, this feature is dropped. For multiple sorting purposes, we recommend to use the \code{subset} parameter instead.
 tableplot <- function(dat, select, subset=NULL, sortCol=1,  decreasing=TRUE, 
 					  nBins=100, from=0, to=100, nCols=ncol(dat),
@@ -87,7 +88,9 @@ tableplot <- function(dat, select, subset=NULL, sortCol=1,  decreasing=TRUE,
 	##################################
 	
 	p <- dat
-	if (!inherits(dat, "prepared")){
+	is_prepared <- inherits(dat, "prepared")
+	
+	if (!is_prepared) {
 		datName <- deparse(substitute(dat))
 		p <- tablePrepare(dat, name=datName)
 	} else datName <- attr(p, "name")
@@ -251,8 +254,11 @@ tableplot <- function(dat, select, subset=NULL, sortCol=1,  decreasing=TRUE,
 						colorNA=colorNA, colorNA_num=colorNA_num, numPals=numPals, nBins=nBins, from=from, 
 						to=to, N=N, n=n)
 	
-	
-	
+	##################################
+	## Clean temp ff objects
+	##################################
+	if (!is_prepared) lapply(p, ff::close.ffdf)
+
 	##################################
 	## Grammar of Graphics, and create difference columns
 	##################################
